@@ -8,7 +8,7 @@ use cargo::{
     ops::{self, PackageOpts, Packages},
     sources::{
         source::{MaybePackage, QueryKind, Source},
-        IndexSummary, RegistrySource,
+        IndexSummary, RegistrySource, SourceConfigMap,
     },
     util::{
         cache_lock::CacheLockMode, interning::InternedString, toml::read_manifest, FileLock,
@@ -41,8 +41,8 @@ pub struct CrateInfo {
     crate_file: FileLock,
     context: GlobalContext,
     source_id: SourceId,
-    excludes: Vec<Pattern>,
-    includes: Vec<Pattern>,
+    excludes: Vec<String>,
+    includes: Vec<String>,
 }
 
 pub type CrateDepInfo = BTreeMap<
@@ -240,7 +240,8 @@ impl CrateInfo {
         );
         let get_package_info = |context: &GlobalContext| -> Result<_> {
             let lock = context.acquire_package_cache_lock(CacheLockMode::DownloadExclusive)?;
-            let mut registry = PackageRegistry::new(context)?;
+            let mut registry =
+                PackageRegistry::new_with_source_config(context, SourceConfigMap::new(context)?)?;
             registry.lock_patches();
             let summaries = fetch_candidates(&mut registry, dependency)?;
             drop(lock);
@@ -573,28 +574,42 @@ impl CrateInfo {
         excludes: Option<&Vec<String>>,
         includes: Option<&Vec<String>>,
     ) {
-        self.excludes = excludes
-            .into_iter()
-            .flatten()
-            .map(|x| Pattern::new(&("*/".to_owned() + x)).unwrap())
-            .collect::<Vec<_>>();
-        self.includes = includes
-            .into_iter()
-            .flatten()
-            .map(|x| Pattern::new(&("*/".to_owned() + x)).unwrap())
-            .collect::<Vec<_>>();
+        self.excludes = excludes.cloned().unwrap_or_default();
+        self.includes = includes.cloned().unwrap_or_default();
     }
 
     pub fn filter_path(&self, path: &Path) -> ::std::result::Result<bool, String> {
-        if self.excludes.iter().any(|p| p.matches_path(path)) {
+        let top_level = path
+            .ancestors()
+            .find(|p| p.parent() == Some(Path::new("")))
+            .unwrap()
+            .to_str()
+            .ok_or_else(|| format!("Failed to get top-level element of {path:?}"))?;
+
+        let matches = move |pattern: &String| -> bool {
+            Pattern::new(&format!("{top_level}/{pattern}"))
+                .unwrap()
+                .matches_path(path)
+        };
+
+        if self.excludes.iter().any(matches) {
             return Ok(true);
         }
         let suspicious = match path.extension() {
             Some(ext) => ext == "c" || ext == "a",
             _ => false,
         };
+
+        let debian_dir_pattern = Pattern::new(&format!("{top_level}/debian/*")).unwrap();
+        if debian_dir_pattern.matches_path(path) {
+            return Err(format!(
+                "Suspicious file or directory, should probably be excluded: {:?}",
+                path
+            ));
+        }
+
         if suspicious {
-            if self.includes.iter().any(|p| p.matches_path(path)) {
+            if self.includes.iter().any(matches) {
                 debcargo_info!("Suspicious file, on whitelist so ignored: {:?}", path);
                 Ok(false)
             } else if testing_ignore_debpolv() {
@@ -611,7 +626,7 @@ impl CrateInfo {
         }
     }
 
-    pub fn extract_crate(&self, path: &Path) -> Result<bool> {
+    pub fn extract_crate(&mut self, path: &Path) -> Result<bool> {
         let mut archive = Archive::new(GzDecoder::new(self.crate_file.file()));
         let tempdir = tempfile::Builder::new()
             .prefix("debcargo")
@@ -682,11 +697,51 @@ impl CrateInfo {
             // if-conditional is supposed to check; modern versions of cargo
             // already do this before uploading the crate and we shouldn't need
             // to handle it specially.
-            let old_toml_path = path.join("Cargo.toml.orig");
-            fs::copy(&toml_path, &old_toml_path)?;
-            let ws = Workspace::new(&toml_path.canonicalize()?, &self.context)?;
+            log::debug!("Cargo.toml not canonicalized..");
+            let orig_toml = actual_toml.clone();
+
+            // Some old uncanonicalized Cargo.toml files contain invalid relative references to
+            // license or readme files that newer cargo doesn't accept anymore.. attempt to monkey
+            // patch them if possible
+            let mut check_reference = |name, value: Option<&str>| {
+                if let Some(referenced_path) = value {
+                    let full_referenced_path = path.join(referenced_path);
+                    if !full_referenced_path.exists() {
+                        debcargo_warn!(
+                            "Cargo.toml references non-existing license_file path: {:?}",
+                            full_referenced_path
+                        );
+                        if let Some((_prefix, file)) = referenced_path.rsplit_once("/") {
+                            if path.join(file).exists() {
+                                debcargo_info!("Replacing reference with '{}'", file);
+                                actual_toml = actual_toml.replace(referenced_path, file);
+                            } else {
+                                debcargo_info!("Removing reference");
+                                actual_toml = actual_toml
+                                    .replace(&format!("{name} = \"{referenced_path}\""), "");
+                            }
+                        } else {
+                            debcargo_info!("Removing reference");
+                            actual_toml =
+                                actual_toml.replace(&format!("{name} = \"{referenced_path}\""), "");
+                        }
+                        return true;
+                    }
+                }
+
+                false
+            };
+
+            if check_reference("license-file", self.metadata().license_file.as_deref())
+                || check_reference("readme", self.metadata().readme.as_deref())
+            {
+                fs::write(&toml_path, actual_toml.as_bytes())?;
+            }
+            let updated = self.replace_manifest(&toml_path.canonicalize()?)?;
+
+            let ws = Workspace::new(&toml_path.canonicalize()?, &updated.context)?;
             let opts = PackageOpts {
-                gctx: &self.context,
+                gctx: &updated.context,
                 list: false,
                 check_metadata: false,
                 allow_dirty: true,
@@ -697,13 +752,16 @@ impl CrateInfo {
                 targets: Vec::new(),
                 cli_features: CliFeatures::new_all(true),
             };
-            let res = cargo::ops::package_one(&ws, &self.package, &opts)?
-                .ok_or_else(|| format_err!("Packaging non-canonicalized crate failed!"))?;
-            let mut archive = Archive::new(GzDecoder::new(res.file()));
+            let res = cargo::ops::package(&ws, &opts)?;
+            let files = res.ok_or_else(|| format_err!("Failed to canonicalize"))?;
+            let file = files
+                .first()
+                .ok_or_else(|| format_err!("No canonicalized archives found.."))?;
+            let mut archive = Archive::new(GzDecoder::new(file.file()));
+
             for entry in archive.entries()? {
                 let mut entry = entry?;
                 let entry_path = entry.path()?;
-                eprintln!("{entry_path:?}");
                 let components = entry_path.iter();
                 if components.clone().count() == 2
                     && components.last() == Some(OsStr::new("Cargo.toml"))
@@ -712,6 +770,7 @@ impl CrateInfo {
                     break;
                 }
             }
+            fs::write(path.join("Cargo.toml.orig"), orig_toml.as_bytes())?;
             std::fs::remove_dir_all(path.join("target"))?;
             source_modified = true;
             // avoid lintian errors about package-contains-ancient-file
@@ -719,6 +778,7 @@ impl CrateInfo {
             // force us to modify them, but otherwise we get that ugly warning
             let last_mtime = FileTime::from_unix_time(last_mtime as i64, 0);
             set_file_times(toml_path, last_mtime, last_mtime)?;
+            debcargo_info!("Cargo.toml manually canonicalized!");
         }
         Ok(source_modified)
     }
