@@ -137,7 +137,7 @@ impl fmt::Display for PkgTest {
         } else {
             format!(", {}", self.depends.join(", "))
         };
-        writeln!(f, "Depends: dh-cargo (>= 18){}, {}", depends, default_deps)?;
+        writeln!(f, "Depends: dh-cargo (>= 31){}, {}", depends, default_deps)?;
 
         let restricts = if self.extra_restricts.is_empty() {
             "".into()
@@ -199,7 +199,7 @@ impl Source {
             priority,
             maintainer,
             uploaders,
-            standards: "4.6.2".to_string(),
+            standards: "4.7.0".to_string(),
             build_deps,
             vcs_git,
             vcs_browser,
@@ -307,7 +307,7 @@ impl Package {
         // https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=901827#35
         // https://wiki.debian.org/Teams/RustPackaging/Policy#Package_provides
         let mut provides = vec![];
-        let version_suffixes = vec![
+        let version_suffixes = [
             "".to_string(),
             format!("-{}", version.major),
             format!("-{}.{}", version.major, version.minor),
@@ -413,7 +413,7 @@ impl Package {
             description,
             extra_lines: vec![
                 "Built-Using: ${cargo:Built-Using}".to_string(),
-                "XB-X-Cargo-Built-Using: ${cargo:X-Cargo-Built-Using}".to_string(),
+                "Static-Built-Using: ${cargo:Static-Built-Using}".to_string(),
             ],
         }
     }
