@@ -5,7 +5,6 @@ struct PkgTestFmtData<'a> {
     extra_test_args: Vec<&'a str>,
     depends: Vec<String>,
     extra_restricts: Vec<&'a str>,
-    expected: &'a str,
 }
 
 #[test]
@@ -16,22 +15,12 @@ fn pkgtest_fmt_has_no_extra_whitespace() {
             extra_test_args: Vec::new(),
             depends: Vec::new(),
             extra_restricts: Vec::new(),
-            expected: r"Test-Command: /usr/share/cargo/bin/cargo-auto-test crate 1.0 --all-targets
-Features: test-name=librust-crate-dev:
-Depends: dh-cargo (>= 18), @
-Restrictions: allow-stderr, skip-not-installable
-",
         },
         PkgTestFmtData {
             feature: "X",
             extra_test_args: vec!["--no-default-features", "--features X"],
             depends: vec!["libfoo-dev".into(), "bar".into()],
             extra_restricts: vec!["flaky"],
-            expected: r"Test-Command: /usr/share/cargo/bin/cargo-auto-test crate 1.0 --all-targets --no-default-features --features X
-Features: test-name=librust-crate-dev:X
-Depends: dh-cargo (>= 18), libfoo-dev, bar, @
-Restrictions: allow-stderr, skip-not-installable, flaky
-",
         },
     ];
 
@@ -47,6 +36,9 @@ Restrictions: allow-stderr, skip-not-installable, flaky
         )
         .unwrap();
 
-        assert_eq!(check.expected, &pkgtest.to_string());
+        for ln in pkgtest.to_string().lines() {
+            let trimmed = ln.trim_end();
+            assert_eq!(trimmed, ln);
+        }
     }
 }
