@@ -1,5 +1,5 @@
 use cargo::core::manifest;
-use chrono::{Datelike, NaiveDateTime, TimeZone, Utc};
+use chrono::{DateTime, Datelike};
 use git2::Repository;
 use regex;
 use tempfile;
@@ -318,21 +318,15 @@ fn copyright_fromgit(repo_url: &str) -> Result<String> {
     let first_commit = repo.find_commit(first_id)?;
     let latest_commit = repo.find_commit(latest_id)?;
 
-    let first_year = Utc
-        .from_utc_datetime(
-            &NaiveDateTime::from_timestamp_opt(first_commit.time().seconds(), 0)
-                .ok_or(anyhow::Error::msg("lo"))?,
-        )
+    let first_year = &DateTime::from_timestamp(first_commit.time().seconds(), 0)
+        .ok_or(anyhow::Error::msg("lo"))?
         .year();
 
-    let latest_year = Utc
-        .from_utc_datetime(
-            &NaiveDateTime::from_timestamp_opt(latest_commit.time().seconds(), 0)
-                .ok_or(anyhow::Error::msg("lo"))?,
-        )
+    let latest_year = &DateTime::from_timestamp(latest_commit.time().seconds(), 0)
+        .ok_or(anyhow::Error::msg("lo"))?
         .year();
 
-    let notice = match first_year.cmp(&latest_year) {
+    let notice = match first_year.cmp(latest_year) {
         Ordering::Equal => format!("{}", first_year),
         _ => format!("{}-{},", first_year, latest_year),
     };
@@ -350,10 +344,7 @@ pub fn debian_copyright(
     guess_harder: bool,
 ) -> Result<DebCopyright> {
     let meta = manifest.metadata().clone();
-    let repository = match meta.repository {
-        None => "",
-        Some(ref r) => r,
-    };
+    let repository = meta.repository.unwrap_or_default();
 
     // The Authors field is optional according to
     // https://rust-lang.github.io/rfcs/3052-optional-authors-field.html
@@ -365,7 +356,7 @@ pub fn debian_copyright(
         &meta.authors
     };
 
-    let upstream = UpstreamInfo::new(manifest.name().to_string(), authors, repository);
+    let upstream = UpstreamInfo::new(manifest.name().to_string(), authors, &repository);
 
     let mut licenses: Vec<License> = Vec::new();
     let mut crate_license: String = "".to_string();
@@ -410,7 +401,7 @@ pub fn debian_copyright(
     // Insert catch all block as the first block of copyright file. Capture
     // copyright notice from git log of the upstream repository.
     let years = if guess_harder && !repository.is_empty() {
-        match copyright_fromgit(repository) {
+        match copyright_fromgit(&repository) {
             Ok(x) => x,
             Err(e) => {
                 debcargo_warn!(
